@@ -104,13 +104,23 @@ See https://www.django-rest-framework.org/community/release-notes/#deprecation-p
 """
 
 
-class RemovedIn24Warning(DeprecationWarning):
-    """Deprecation warning for features that will be removed in version 2.4.0."""
+class RemovedIn25Warning(DeprecationWarning):
+    """Deprecation warning for features that will be removed in version 2.5.0."""
 
     pass
 
 
-class RemovedIn25Warning(PendingDeprecationWarning):
-    """Pending deprecation warning for features that will be removed in version 2.5.0."""
+class RemovedIn26Warning(PendingDeprecationWarning):
+    """Pending deprecation warning for features that will be removed in version 2.6.0."""
 
     pass
+
+
+class APIDeprecationWarning(DeprecationWarning):
+    """
+    Features that are deprecated in the Mollie API.
+
+    This library cannot control when an API feature will be removed. We can only label it as 'deprecated'
+    using this warning, and hope that library users stop using the feature before the removal.
+    """
+    pass
